##########
# Import #
##########
# data_X_t1 is the full population of each vaccine arm + its controls
# data_X_KM and data_X_VE only include the population that survived at least 7 days from start of follow-up


#############
# Table One #
#############
# Table 1 - Enrolled
t1 <- CreateTableOne(data = data_pfizer_t1, strata = "vac_type_fact",
                     vars = c("age", "sex", "sector", "bmi", "Immunosupressed", 
                              "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                              "autoimmune", "number_comorb_fact", "days_contributed", 
                              "infection", "any_symptom", "fever_above_38", "fever_days", "days_at_bed", 
                              "two_or_more_days_at_bed", "three_or_more_days_at_bed"), 
                     factorVars = c("sex", "sector", "Immunosupressed", "number_comorb_fact",
                                    "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                                    "autoimmune",
                                    "infection", "any_symptom", "fever_above_38",  
                                    "two_or_more_days_at_bed", "three_or_more_days_at_bed"))
View(print(t1, missing = T, test=F, nonnormal=c("age", "bmi", "days_contributed", "fever_days", "days_at_bed")))

t1 <- CreateTableOne(data = data_moderna_t1, strata = "vac_type_fact",
                     vars = c("age", "sex", "sector", "bmi", "Immunosupressed", 
                              "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                              "autoimmune", "number_comorb_fact", "days_contributed", 
                              "infection", "any_symptom", "fever_above_38", "fever_days", "days_at_bed", 
                              "two_or_more_days_at_bed", "three_or_more_days_at_bed"),
                     factorVars = c("sex", "sector", "Immunosupressed", "number_comorb_fact",
                                    "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                                    "autoimmune",
                                    "infection", "any_symptom", "fever_above_38",  
                                    "two_or_more_days_at_bed", "three_or_more_days_at_bed"))
View(print(t1, missing = T, test=F, nonnormal=c("age", "bmi", "days_contributed", "fever_days", "days_at_bed")))

# Table 1 - Analyzed
t1 <- CreateTableOne(data = data_pfizer_KM, strata = "vac_type_fact",
                     vars = c("age", "sex", "sector", "bmi", "Immunosupressed", 
                              "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                              "autoimmune", "number_comorb_fact", "days_contributed", 
                              "infection", "any_symptom", "fever_above_38", "fever_days", "days_at_bed", 
                              "two_or_more_days_at_bed", "three_or_more_days_at_bed"), 
                     factorVars = c("sex", "sector", "Immunosupressed", "number_comorb_fact",
                                    "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                                    "autoimmune",
                                    "infection", "any_symptom", "fever_above_38",  
                                    "two_or_more_days_at_bed", "three_or_more_days_at_bed"))
View(print(t1, missing = T, test=F, nonnormal=c("age", "bmi", "days_contributed", "fever_days", "days_at_bed")))

t1 <- CreateTableOne(data = data_moderna_KM, strata = "vac_type_fact",
                     vars = c("age", "sex", "sector", "bmi", "Immunosupressed", 
                              "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                              "autoimmune", "number_comorb_fact", "days_contributed", 
                              "infection", "any_symptom", "fever_above_38", "fever_days", "days_at_bed", 
                              "two_or_more_days_at_bed", "three_or_more_days_at_bed"),
                     factorVars = c("sex", "sector", "Immunosupressed", "number_comorb_fact",
                                    "hypertension", "diabetes", "lung", "heart", "liver", "ckd", 
                                    "autoimmune",
                                    "infection", "any_symptom", "fever_above_38",  
                                    "two_or_more_days_at_bed", "three_or_more_days_at_bed"))
View(print(t1, missing = T, test=F, nonnormal=c("age", "bmi", "days_contributed", "fever_days", "days_at_bed")))




#######
# KMs #
#######
# Pfizer
fit <- survfit(Surv(days_contributed, infection) ~ vac_type, data = data_pfizer_KM)

ggsurvplot(
  fit,
  fun = "event",
  palette = c("darkorange3", "springgreen4"),
  surv.scale = "percent",
  risk.table = T,
  cumevents = T,
  #data = data_pfizer,
  pval = F,
  #pval.coord = c(0,0095),
  conf.int = TRUE,
  #start.time = 0,
  axes.offset = F,
  xlim = c(5, 102),
  ylim = c(0, 1),
  break.time.by = 7,
  ggtheme = theme_bw(),
  risk.table.y.text = FALSE,
  legend.labs = c("BNT162b2", "Control"),
  legend.title = element_blank(),
  title = "Cumulative Incidence (BNT162b2 vs. Controls)",
  legend = "bottom",
  xlab = "Time from 4th Dose (days)",
  ylab = "Cumulative Incidence (%)",
  fontsize = 4,
  size = 0.75,
  censor = F
  #risk.table.fontsize = 3
)

fit <- survfit(Surv(days_contributed, two_or_more_days_at_bed) ~ vac_type, data = data_pfizer_KM)

ggsurvplot(
  fit,
  fun = "event",
  palette = c("darkorange3", "springgreen4"),
  surv.scale = "percent",
  risk.table = T,
  cumevents = T,
  #data = data_pfizer,
  pval = F,
  #pval.coord = c(0,0095),
  conf.int = TRUE,
  #start.time = 0,
  axes.offset = F,
  xlim = c(5, 102),
  ylim = c(0, 0.5),
  break.time.by = 7,
  ggtheme = theme_bw(),
  risk.table.y.text = FALSE,
  legend.labs = c("BNT162b2", "Control"),
  legend.title = element_blank(),
  title = "Cumulative Incidence (BNT162b2 vs. Controls)",
  legend = "bottom",
  xlab = "Time from 4th Dose (days)",
  ylab = "Cumulative Incidence (%)",
  fontsize = 4,
  size = 0.75,
  censor = F
  #risk.table.fontsize = 3
)


# Moderna
fit <- survfit(Surv(days_contributed, infection) ~ vac_type, data = data_moderna_KM)

ggsurvplot(
  fit,
  fun = "event",
  palette = c("royalblue4", "springgreen4"),
  surv.scale = "percent",
  risk.table = T,
  cumevents = T,
  #data = data_KM %>% filter(vac_type != 2),
  pval = F,
  #pval.coord = c(0,0095),
  conf.int = T,
  axes.offset = F,
  xlim = c(5, 102),
  ylim = c(0, 1),
  break.time.by = 7,
  ggtheme = theme_bw(),
  risk.table.y.text = FALSE,
  legend.labs = c("mRNA1273", "Control"),
  legend.title = element_blank(),
  title = "Cumulative Incidence (mRNA1273 vs. Controls)",
  legend = "bottom",
  xlab = "Time from 4th Dose (days)",
  ylab = "Cumulative Incidence (%)",
  fontsize = 4,
  size = 0.75,
  censor = F
  #risk.table.fontsize = 3
)

fit <- survfit(Surv(days_contributed, two_or_more_days_at_bed) ~ vac_type, data = data_moderna_KM)

ggsurvplot(
  fit,
  fun = "event",
  palette = c("royalblue4", "springgreen4"),
  surv.scale = "percent",
  risk.table = T,
  cumevents = T,
  #data = data_KM %>% filter(vac_type != 2),
  pval = F,
  #pval.coord = c(0,0095),
  conf.int = T,
  axes.offset = F,
  xlim = c(5, 102),
  ylim = c(0, 0.5),
  break.time.by = 7,
  ggtheme = theme_bw(),
  risk.table.y.text = FALSE,
  legend.labs = c("mRNA1273", "Control"),
  legend.title = element_blank(),
  title = "Cumulative Incidence (mRNA1273 vs. Controls)",
  legend = "bottom",
  xlab = "Time from 4th Dose (days)",
  ylab = "Cumulative Incidence (%)",
  fontsize = 4,
  size = 0.75,
  censor = F
  #risk.table.fontsize = 3
)


############
# Adjusted #
############
plot_df <- data.frame(vacc = character(0), outcome = character(0), point = numeric(0), upper = numeric(0), lower = numeric(0))

# infection
fit <- glm(infection ~ vac_type_fact + age + sex, offset = log(days_contributed), 
           data = data_pfizer_VE, family = "poisson")
tidy_fit <- tidy(fit, conf.int = T, exponentiate = T)

plot_df[nrow(plot_df)+1,] <- c("BNT162b2", "Infection", 1-tidy_fit[2,2], 1-tidy_fit[2,6], 1-tidy_fit[2,7])

fit <- glm(infection ~ vac_type_fact + age + sex, offset = log(days_contributed), 
           data = data_moderna_VE, family = "poisson")
tidy_fit <- tidy(fit, conf.int = T, exponentiate = T)

plot_df[nrow(plot_df)+1,] <- c("mRNA1273", "Infection", 1-tidy_fit[2,2], 1-tidy_fit[2,6], 1-tidy_fit[2,7])

# two or more days at bed
fit <- glm(two_or_more_days_at_bed ~ vac_type_fact + age + sex, offset = log(days_contributed), 
           data = data_pfizer_VE, family = "poisson")
tidy_fit <- tidy(fit, conf.int = T, exponentiate = T)

plot_df[nrow(plot_df)+1,] <- c("BNT162b2", "Substantial Disease", 1-tidy_fit[2,2], 1-tidy_fit[2,6], 1-tidy_fit[2,7])

fit <- glm(two_or_more_days_at_bed ~ vac_type_fact + age + sex, offset = log(days_contributed), 
           data = data_moderna_VE, family = "poisson")
tidy_fit <- tidy(fit, conf.int = T, exponentiate = T)

plot_df[nrow(plot_df)+1,] <- c("mRNA1273", "Substantial Disease", 1-tidy_fit[2,2], 1-tidy_fit[2,6], 1-tidy_fit[2,7])


###############
# Forest Plot #
###############
plot_df <- 
  plot_df %>% 
  mutate(vacc = fct_relevel(vacc, "BNT162b2", "mRNA1273")) %>% 
  mutate(outcome = fct_relevel(outcome, "Infection", "Substantial Disease")) %>% 
  mutate_if(is.numeric, round, 3)

plot_df

ggplot(plot_df, aes(vacc, point, ymin = lower, ymax = upper, color = vacc)) +
  geom_point(size = 4) +
  #geom_point(size = 4, shape = 3, stroke = 2) +
  geom_errorbar(width = 0.2, size = 2) +
  geom_hline(yintercept = 0, linetype = "dashed", color = "black") +
  scale_y_continuous(labels = scales::percent) +
  scale_color_manual(values = c("darkorange3", "royalblue4")) +
  theme_bw() +
  facet_grid(cols = vars(outcome)) +
  xlab("Vaccination Type") +
  ylab("Vaccine Efficacy") +
  theme(legend.position = "none")